@@ -31,7 +31,7 @@ class DigitalI2c(AbstractDwfDeviceSubApi):
     def clear(self) -> bool:
         """Clear the I²C bus.
 
-        Verify and try to solve an I²C bus lockup condition.
+        Detect and try to solve an I²C bus lockup condition.
 
         Todo:
             The precise behavior of this method needs to be understood and documented.
@@ -66,11 +66,11 @@ class DigitalI2c(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def rateSet(self, data_rate: float) -> None:
-        """Set  I²C data rate, in Hz.
+        """Set the I²C data rate, in Hz.
 
         Parameters:
             data_rate (float): I²C data rate. Often-encountered rates are 100 kHz and 400 kHz, but many
-                modern I²C devices support higher data rates. Check the datasheet.
+                modern I²C devices support higher data rates. Check the datasheet of your device.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -96,7 +96,7 @@ class DigitalI2c(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def sclSet(self, channel_index: int) -> None:
-        """Set the digital channel (pin) where the clock (SCL) signal is transmitted.
+        """Set the digital channel (pin) where the I²C clock (SCL) signal is transmitted.
 
         Parameters:
             channel_index (int): The channel (digital pin number) on which to generate the SCL clock.
@@ -109,7 +109,7 @@ class DigitalI2c(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def sdaSet(self, channel_index: int) -> None:
-        """Set the digital channel (pin) where the data (SDA) signal is transmitted/received.
+        """Set the digital channel (pin) where the I²C data (SDA) signal is transmitted/received.
 
         Parameters:
             channel_index (int): The channel (digital pin number) on which to send/receive SDA data.
@@ -122,7 +122,7 @@ class DigitalI2c(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def writeRead(self, address: int, tx: List[int], number_of_rx_bytes: int) -> Tuple[int, List[int]]:
-        """Perform an I²C combined write/read operation.
+        """Perform a combined I²C write/read operation.
 
         Parameters:
             address (int): The I²C address of the target device.
