@@ -20,7 +20,7 @@ class AbstractDwfDeviceSubApi:
         but we need the |DwfDevice| itself.
 
         Returns:
-            DwfDevice: The |DwfDevice| that this attribute belongs to.
+            DwfDevice: The |DwfDevice| instance that this attribute belongs to.
         """
         return self._device
 
@@ -28,10 +28,10 @@ class AbstractDwfDeviceSubApi:
     def hdwf(self):
         """Return the HDWF device handle.
 
+        :meta private:
+
         Returns:
             int: The HDWF device handle.
-
-        :meta private:
         """
         return self.device.hdwf
 
@@ -39,20 +39,21 @@ class AbstractDwfDeviceSubApi:
     def dwf(self):
         """Return the |DwfLibrary| instance.
 
+        :meta private:
+
         Returns:
             DwfLibrary: The |DwfLibrary| instance.
 
-        :meta private:
         """
         return self.device.dwf
 
     @property
     def lib(self):
-        """Return the |ctypes:link| library.
-
-        Returns:
-            ctypes.CDLL: The |ctypes| library.
+        """Return the *ctypes* library.
 
         :meta private:
+
+        Returns:
+            ctypes.CDLL: The *ctypes* library.
         """
         return self.dwf.lib
